-----------------------------------------------------------------------
-- Locale
-----------------------------------------------------------------------
local L = AceLibrary("AceLocale-2.2"):new("Violation")

L:RegisterTranslations("enUS", function() return {
	-- nothing here yet
} end)

-----------------------------------------------------------------------
-- Locals
-----------------------------------------------------------------------
local tablet = AceLibrary("Tablet-2.0")
local parser = AceLibrary("Parser-3.0")
local BC = AceLibrary("Babble-Class-2.2")
local roster = AceLibrary("Roster-2.1")

local playerName = nil

local coloredNames = setmetatable({}, {__index =
	function(self, key)
		local obj = roster:GetUnitObjectFromName(key)
		if not obj then return nil end
		self[key] = "|cff" .. BC:GetHexColor(obj.class) .. key .. "|r"
		return self[key]
	end
})

local data = nil
local dirty = nil

local _G = getfenv(0)

-----------------------------------------------------------------------
-- Addon initialization
-----------------------------------------------------------------------
Violation = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0", "AceHook-2.1", "AceDB-2.0", "AceConsole-2.0", "AceComm-2.0", "FuBarPlugin-2.0")
local Violation = Violation

Violation.hasIcon = "Interface\\Icons\\Spell_ChargePositive"

function Violation:OnInitialize()
	local revision = tonumber(("$Revision: 28332 $"):sub(12, -3)) or 1
	if not self.version then self.version = "1.0" end
	self.version = self.version .. "." .. revision
	self.revision = revision

	_G.VIOLATION_VERSION = self.version
	_G.VIOLATION_REVISION = self.revision

	playerName = UnitName("player")
end

function Violation:OnEnable()
	Violation:Reset()
	parser:Register({ eventType = "Damage" }, self.OnCombatEvent, self)

	self:SetCommPrefix("Violation")
	self:SetDefaultCommPriority("BULK")
	self:RegisterComm("Violation", "GROUP", "OnComm")

	self:ScheduleRepeatingEvent("DamageBroadcast", self.Broadcast, 5, self)
end

function Violation:Reset()
	data = {
		[playerName] = 0
	}
end

-----------------------------------------------------------------------
-- UI
-----------------------------------------------------------------------
function Violation:OnTooltipUpdate()
	local cat = tablet:AddCategory(
		"columns", 2
	)
	for k, v in pairs(data) do
		if type(v) == "number" and v > 0 then
			cat:AddLine("text", coloredNames[k], "text2", tostring(v or 0))
		end
	end
end

-----------------------------------------------------------------------
-- Data broadcasting and recieving
-----------------------------------------------------------------------
function Violation:Broadcast()
	if not dirty then return end
	dirty = nil
	self:SendCommMessage("GROUP", data[playerName])
end

function Violation:OnComm(prefix, sender, distribution, damage)
	if distribution ~= "GROUP" then return end
	data[sender] = damage
end

-----------------------------------------------------------------------
-- Combat log parsing
-----------------------------------------------------------------------
function Violation:OnCombatEvent(t)
	if t.amount and t.sourceName and t.sourceName == "player" then
		data[playerName] = data[playerName] + t.amount
		dirty = true
		self:UpdateTooltip()
	end
end

